/*
 * TimeRTC for DS1337
 * example code illustrating Time library with Real Time Clock.
 *
 * DS1337 の現在の日時を読み出してシリアルモニターに転送するスケッチ例
 *
 * Copyright (C) 2013 I.Kato @ BS21Lab.
 *
 * The sketch is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This sketch is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this sketch; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include <Time.h>
#include <Wire.h>
#include <DS1337RTC.h>  // a basic DS1337 library that returns time as a time_t

void setup()
{
  Serial.begin(9600);
  while (!Serial) {
    ; // wait for serial port to connect. Needed for Leonardo only
  }

  RTC.powerOffWithoutWaking();  // 目覚めよ！xxduino！シールドのアラーム１出力を強制 OFF します。単四電池の供給が停止するので、USB 接続されていないと Arduino も停止します。

  // Time ライブラリに DS1337 の getCurrTime 関数を渡します。以降、Time ライブラリ内で DS1337 の日時が取得されます。
  setSyncProvider(RTC.getCurrTime);   // the function to get the time from the RTC

  if (timeStatus() != timeSet)
    Serial.println("Unable to sync with the RTC");
  else
    Serial.println("RTC has set the system time");
}

void loop()
{
  digitalClockDisplay();   // 1秒ごとにシリアルモニタに日時を転送する
  delay(1000);
}

void digitalClockDisplay()
{
  // digital clock display of the time
  Serial.print(hour());
  printDigits(minute());
  printDigits(second());
  Serial.print(" ");
  Serial.print(day());
  Serial.print("/");
  Serial.print(monthShortStr(month()));  // 月は JAN とかで表示する
  Serial.print("/");
  Serial.print(year());
  Serial.print(" (");
  Serial.print(dayShortStr(weekday()));  // 曜日は SUN とかで表示する
  Serial.println(")");
}

void printDigits(int digits)
{
  // utility function for digital clock display: prints preceding colon and leading 0
  Serial.print(":");
  if (digits < 10)
    Serial.print('0');
  Serial.print(digits);
}

