/*
 * wakeup_1min_demo for DS1337RTC
 * example code illustrating Time library with Real Time Clock.
 *
 * １分ごとに Arduino を起動させるスケッチ例
 *
 *   目覚めよ！xxduino！シールドを接続した Arduino に、このスケッチを転送し、USB ケーブルを外します。
 *   すると、毎分 00 秒目に DS1337 のアラームが発生し、Arduino に９Ｖを供給開始します。
 *   8ピンに繋がった LED を５秒だけ点灯させてから、９Ｖ供給を停止します。
 *   このシーケンスを単四電池が消耗するまで繰り返します。
 *   注意：既に DS1337 には現在の日時が設定されている必要が有ります。
 *
 * Copyright (C) 2013 I.Kato @ BS21Lab.
 *
 * The sketch is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This sketch is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this sketch; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <Time.h>
#include <Wire.h>
#include <DS1337RTC.h>

int ledPin =  8;        // デジタル８ピンに LED を接続します

void setup()
{
  pinMode     (ledPin, OUTPUT);  // 8ピンを出力にする
  digitalWrite(ledPin, LOW);     // とりあえず LED は OFF

  if (RTC.getWakeupFlag()) {     // RTC アラームで９Ｖが供給された時
    digitalWrite(ledPin, HIGH);  // LED を ON
    delay(5000);                 // ５秒間キープ
    RTC.powerOff();              // 目覚めよ！xxduino！シールドの９Ｖ供給を停止します。
    digitalWrite(ledPin, LOW);   // DS1337RTC::powerOff 関数以降のスケッチは呼び出される事はありません。
  } else {
    // Arduino 本体に USB 接続で５Ｖ供給された時か、目覚めよ！xxduino！シールド上の強制出力ONスイッチ(SS1)がオンにされた時
    ;  // 何もしない
  }

  // Arduino 本体に USB 接続で５Ｖ供給された時か、目覚めよ！xxduino！シールド上の強制出力ONスイッチ(SS1)がオンにされた時
  // RTC アラームで９Ｖが供給された時は、すでに powerOff されているので、ここに達することはありません。
  RTC.setWakeupTimeEveryMin  (                          0);  // RTC の           秒が                    00秒の時に wakeup する様に、DS1337 に設定します
//RTC.setWakeupTimeEveryHour (                       0, 0);  // RTC の        分/秒が                00分00秒の時に wakeup する様に、DS1337 に設定します
//RTC.setWakeupTimeEveryDay  (                   12, 0, 0);  // RTC の     時/分/秒が            12時00分00秒の時に wakeup する様に、DS1337 に設定します
//RTC.setWakeupTimeEveryWeek (DS1337RTC_DOW_SUN, 12, 0, 0);  // RTC の曜日/時/分/秒が 毎週日曜日 12時00分00秒の時に wakeup する様に、DS1337 に設定します
//RTC.setWakeupTimeEveryMonth(10,                12, 0, 0);  // RTC の  日/時/分/秒が 毎月10日の 12時00分00秒の時に wakeup する様に、DS1337 に設定します
}

void loop()
{
}

