/*
 * wakeup_1min_demo for DS1337RTC
 * example code illustrating Time library with Real Time Clock.
 *
 * ５分ごとに Arduino を起動させるスケッチ例
 *
 *   目覚めよ！xxduino！シールドを接続した Arduino に、このスケッチを転送し、USB ケーブルを外します。
 *   すると、毎時 00分/05分/10分/15分/20分/25分/30分/35分/40分/45分/50分/55分 00 秒目に DS1337 のアラームが発生し、Arduino に９Ｖを供給開始します。
 *   8ピンに繋がった LED を５秒だけ点灯させてから、９Ｖ供給を停止します。
 *   このシーケンスを単四電池が消耗するまで繰り返します。
 *   注意：既に DS1337 には現在の日時が設定されている必要が有ります。
 *
 * Copyright (C) 2013 I.Kato @ BS21Lab.
 *
 * The sketch is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This sketch is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this sketch; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <Time.h>
#include <Wire.h>
#include <DS1337RTC.h>

int ledPin =  8;        // デジタル８ピンに LED を接続します

void setup()
{
  pinMode     (ledPin, OUTPUT);  // 8ピンを出力にする
  digitalWrite(ledPin, LOW);     // とりあえず LED は OFF

  if (RTC.getWakeupFlag()) {     // RTC アラームで９Ｖが供給された時
    digitalWrite(ledPin, HIGH);  // LED を ON
    delay(5000);                 // ５秒間キープ
    digitalWrite(ledPin, LOW);   // DS1337RTC::powerOff 関数以降のスケッチは呼び出される事はありません。
  } else {
    // Arduino 本体に USB 接続で５Ｖ供給された時か、目覚めよ！xxduino！シールド上の強制出力ONスイッチ(SS1)がオンにされた時
    ;  // 何もしない
  }

  tmElements_t tm;
  RTC.getCurrTime (tm);  // 現在の日時を取得

  uint8_t m = tm.Minute + 5; // ５分を加算
  if (m >= 60) {  // 60分を超えた時は00分に戻す
    m = 0;
  }
  m = m / 5;  // 一旦、５で割って、0～11 にする
  m = m * 5;  // それを５倍すれば、５分刻みになる

  tm.Minute = m;  // 分は５分刻み
  tm.Second = 0;  // 秒は常に 00 秒にする
  RTC.setWakeupTimeEveryHour (tm);  // 次に wakeup する分/秒を DS1337 に設定します

  delay(1);  // 保険で 1msec 待たせる

  RTC.powerOff();  // 目覚めよ！xxduino！シールドの９Ｖ供給を停止します。
}

void loop()
{
}

